/*     */ package com.netapp.asup.config;
/*     */ 
/*     */ import com.netapp.asup.common.AsupLogger;
/*     */ import com.netapp.asup.exception.ARMAConfigurationException;
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.net.URL;
/*     */ import java.util.Map;
/*     */ import java.util.Properties;
/*     */ import java.util.concurrent.ConcurrentHashMap;
/*     */ import java.util.concurrent.ConcurrentMap;
/*     */ 
/*     */ 
/*     */ public class ARMAConfiguration
/*     */   implements Configuration
/*     */ {
/*  17 */   private static final AsupLogger LOG = AsupLogger.getLogger(ARMAConfiguration.class);
/*     */   
/*  19 */   private static final ConcurrentMap<ClassLoader, Map<String, Class<?>>> CACHE_CLASSES = new ConcurrentHashMap();
/*     */   
/*     */   private Properties properties;
/*     */   private static final String SERVER_CONFIG_PROPERTIES = "arma_server_config.properties";
/*     */   private static final String CLIENT_CONFIG_PROPERTIES = "arma_client_config.properties";
/*     */   private ClassLoader classLoader;
/*     */   
/*     */   public void loadDefaultResource(String resourceName)
/*     */     throws ARMAConfigurationException
/*     */   {
/*  29 */     InputStream resourceAsStream = getClass().getClassLoader().getResourceAsStream(resourceName);
/*  30 */     if (null == resourceAsStream) {
/*  31 */       LOG.warn("-9999", "The default configuration is not avaialble:" + resourceName);
/*  32 */       return;
/*     */     }
/*     */     try {
/*  35 */       loadResource(resourceAsStream);
/*     */     } catch (IOException e) {
/*  37 */       throw new ARMAConfigurationException(LOG, "Unable to load the default configuration file:" + resourceName, e);
/*     */     }
/*     */   }
/*     */   
/*     */   private void loadResource(InputStream resourceAsStream) throws IOException {
/*  42 */     this.properties.load(resourceAsStream);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public ARMAConfiguration()
/*     */     throws ARMAConfigurationException
/*     */   {
/*  53 */     this.classLoader = Thread.currentThread().getContextClassLoader();
/*  54 */     if (this.classLoader == null) {
/*  55 */       this.classLoader = ARMAConfiguration.class.getClassLoader();
/*     */     }
/*  46 */     this.properties = new Properties();
/*  47 */     loadDefaultResource("arma_server_config.properties");
/*  48 */     loadDefaultResource("arma_client_config.properties");
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public URL getResource(String name)
/*     */   {
/*  66 */     return this.classLoader.getResource(name);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public String getTrimmed(String name)
/*     */   {
/*  77 */     if (null == name) {
/*  78 */       return null;
/*     */     }
/*  80 */     String value = get(name);
/*     */     
/*  82 */     if (null == value) {
/*  83 */       return null;
/*     */     }
/*  85 */     return value.trim();
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public String get(String name)
/*     */   {
/*  97 */     return this.properties.getProperty(name);
/*     */   }
/*     */   
/*     */   public Properties getAllProperties() {
/* 101 */     return this.properties;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void set(String name, String value)
/*     */   {
/* 111 */     if (isEmpty(name)) {
/* 112 */       LOG.warn("-9999", "Invalid configuration key is provided:" + name);
/* 113 */       return;
/*     */     }
/* 115 */     if (value == null) {
/* 116 */       LOG.warn("-9999", "Invalid configuration value is provided:" + value);
/* 117 */       return;
/*     */     }
/* 119 */     this.properties.setProperty(name, value);
/*     */   }
/*     */   
/*     */   public void setString(String name, String... values) {
/* 123 */     set(name, arrayToString(values));
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void setInt(String name, int value)
/*     */   {
/* 133 */     set(name, Integer.toString(value));
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void setDouble(String name, double value)
/*     */   {
/* 143 */     set(name, Double.toString(value));
/*     */   }
/*     */   
/*     */   public static String arrayToString(String[] strs) {
/* 147 */     if (null == strs) {
/* 148 */       return null;
/*     */     }
/* 150 */     if (strs.length == 0) {
/* 151 */       return "";
/*     */     }
/* 153 */     StringBuffer sbuf = new StringBuffer();
/* 154 */     sbuf.append(strs[0]);
/* 155 */     for (int idx = 1; idx < strs.length; idx++) {
/* 156 */       sbuf.append(",");
/* 157 */       sbuf.append(strs[idx]);
/*     */     }
/* 159 */     return sbuf.toString();
/*     */   }
/*     */   
/*     */   public String getString(String name) {
/* 163 */     if (isEmpty(name)) {
/* 164 */       LOG.warn("-9999", "Invalid configuration key is provided:" + name);
/* 165 */       return null;
/*     */     }
/* 167 */     return this.properties.getProperty(name);
/*     */   }
/*     */   
/*     */   private boolean isEmpty(String name) {
/* 171 */     if ((null == name) || (name.length() <= 0)) {
/* 172 */       return true;
/*     */     }
/* 174 */     return false;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public int getInt(String name, int defaultValue)
/*     */   {
/* 186 */     String valueString = getTrimmed(name);
/* 187 */     if (valueString == null)
/* 188 */       return defaultValue;
/*     */     try {
/* 190 */       return Integer.parseInt(valueString);
/*     */     } catch (NumberFormatException e) {}
/* 192 */     return defaultValue;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public String getString(String name, String defaultValue)
/*     */   {
/* 206 */     String valueString = getTrimmed(name);
/* 207 */     if (valueString != null) {
/* 208 */       return valueString;
/*     */     }
/* 210 */     return defaultValue;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public double getDouble(String name, double defaultValue)
/*     */   {
/* 222 */     String valueString = getTrimmed(name);
/* 223 */     if (valueString == null)
/* 224 */       return defaultValue;
/*     */     try {
/* 226 */       return Double.parseDouble(valueString);
/*     */     } catch (NumberFormatException e) {}
/* 228 */     return defaultValue;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public Class<?> getClass(String name, Class<?> defaultValue)
/*     */   {
/* 240 */     String valueString = getTrimmed(name);
/* 241 */     if (valueString == null)
/* 242 */       return defaultValue;
/*     */     try {
/* 244 */       return getClassByName(valueString);
/*     */     } catch (ClassNotFoundException e) {
/* 246 */       throw new RuntimeException(e);
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public Class<?> getClassByName(String name)
/*     */     throws ClassNotFoundException
/*     */   {
/* 258 */     Map<String, Class<?>> map = (Map)CACHE_CLASSES.get(this.classLoader);
/* 259 */     if (map == null) {
/* 260 */       Map<String, Class<?>> newMap = new ConcurrentHashMap();
/* 261 */       map = (Map)CACHE_CLASSES.putIfAbsent(this.classLoader, newMap);
/* 262 */       if (map == null) {
/* 263 */         map = newMap;
/*     */       }
/*     */     }
/*     */     
/* 267 */     Class<?> clazz = (Class)map.get(name);
/* 268 */     if (clazz == null) {
/* 269 */       clazz = Class.forName(name, true, this.classLoader);
/* 270 */       if (clazz != null) {
/* 271 */         map.put(name, clazz);
/*     */       }
/*     */     }
/*     */     
/* 275 */     return clazz;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void setClass(String name, Class<?> theClass)
/*     */   {
/* 286 */     if (null == theClass) {
/* 287 */       LOG.warn("-9999", "Invalid class value:" + theClass);
/* 288 */       return;
/*     */     }
/* 290 */     set(name, theClass.getName());
/*     */   }
/*     */   
/*     */   public Properties getProperties() {
/* 294 */     return this.properties;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\netapp\asup\config\ARMAConfiguration.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */