/*     */ package com.netapp.asup.data.function.sort;
/*     */ 
/*     */ import com.netapp.asup.client.arma.data.ARMAObjectInstance;
/*     */ import com.netapp.asup.common.AsupLogger;
/*     */ import com.netapp.asup.data.function.FunctionAttribute;
/*     */ import com.netapp.asup.data.function.TypeConverter;
/*     */ import com.netapp.asup.data.function.aggregation.ExpressionAggregator.Converter;
/*     */ import com.netapp.asup.exception.ARMAException;
/*     */ import java.lang.reflect.InvocationTargetException;
/*     */ import java.util.Comparator;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import org.apache.avro.util.Utf8;
/*     */ import org.codehaus.commons.compiler.CompileException;
/*     */ import org.codehaus.janino.ExpressionEvaluator;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class ExpressionComparator
/*     */   implements Comparator<ARMAObjectInstance>
/*     */ {
/*     */   private SortType sortType;
/*     */   private String expression;
/*     */   private Class<?> expressionType;
/*     */   private List<FunctionAttribute> attributes;
/*     */   private final ExpressionEvaluator eval;
/*  28 */   protected static final AsupLogger logger = AsupLogger.getLogger(ExpressionComparator.class);
/*     */   
/*     */ 
/*     */ 
/*     */   public ExpressionComparator(SortType sortType, String expression, Class<?> expressionType, List<FunctionAttribute> attributes)
/*     */   {
/*  34 */     this.sortType = sortType;
/*  35 */     this.expression = expression;
/*  36 */     this.expressionType = expressionType;
/*  37 */     this.attributes = attributes;
/*     */     
/*  39 */     String[] attrNames = new String[attributes.size()];
/*  40 */     Class<?>[] attributeTypes = new Class[attributes.size()];
/*     */     
/*  42 */     int index = 0;
/*  43 */     for (FunctionAttribute functionAttribute : attributes) {
/*  44 */       attrNames[index] = functionAttribute.getAttrName();
/*  45 */       attributeTypes[index] = functionAttribute.getAttrType();
/*  46 */       index++;
/*     */     }
/*     */     try
/*     */     {
/*  50 */       this.eval = new ExpressionEvaluator(this.expression, Object.class, attrNames, attributeTypes);
/*     */     }
/*     */     catch (CompileException e) {
/*  53 */       ARMAException armaException = new ARMAException(logger, expression, "Invalid expression caused by :" + e.getCause(), e);
/*     */       
/*  55 */       throw new IllegalArgumentException(armaException);
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */   public int compare(ARMAObjectInstance o1, ARMAObjectInstance o2)
/*     */   {
/*  62 */     Object[] attrValues1 = new Object[this.attributes.size()];
/*  63 */     Object[] attrValues2 = new Object[this.attributes.size()];
/*     */     
/*  65 */     int index = 0;
/*     */     
/*     */     try
/*     */     {
/*  69 */       for (FunctionAttribute attr : this.attributes)
/*     */       {
/*  71 */         String attributeValue = o1.getAllAttribute(attr.getAttrName());
/*  72 */         if (null == attributeValue) {
/*  73 */           logger.warn(o1.getKey().toString(), "Attribute :" + attr.getAttrName() + " has null value");
/*     */           
/*     */ 
/*  76 */           return 0;
/*     */         }
/*     */         
/*  79 */         attrValues1[index] = ((ExpressionAggregator.Converter)TypeConverter.getConvertorclassmap().get(attr.getAttrType())).convert(attributeValue);
/*     */         
/*     */ 
/*  82 */         attributeValue = o2.getAllAttribute(attr.getAttrName());
/*     */         
/*  84 */         if (null == attributeValue) {
/*  85 */           logger.warn(o2.getKey().toString(), "Attribute :" + attr.getAttrName() + " has null value");
/*     */           
/*     */ 
/*  88 */           return 0;
/*     */         }
/*     */         
/*  91 */         attrValues2[index] = ((ExpressionAggregator.Converter)TypeConverter.getConvertorclassmap().get(attr.getAttrType())).convert(o2.getAllAttribute(attr.getAttrName()));
/*     */         
/*     */ 
/*     */ 
/*  95 */         index++;
/*     */       }
/*     */       
/*  98 */       Object evaluate1 = this.eval.evaluate(attrValues1);
/*  99 */       Object evaluate2 = this.eval.evaluate(attrValues2);
/*     */       
/* 101 */       if ((evaluate1 == null) || (evaluate2 == null)) {
/* 102 */         return 0;
/*     */       }
/*     */       
/* 105 */       return Comparators.compare(this.expression, String.valueOf(evaluate1), String.valueOf(evaluate1), this.expressionType, this.sortType);
/*     */     }
/*     */     catch (InvocationTargetException e)
/*     */     {
/* 109 */       ARMAException armaException = new ARMAException(logger, this.expression, "Error in execution of expression :" + e.getCause(), e);
/*     */       
/*     */ 
/* 112 */       throw new IllegalArgumentException("Comparison function failure:", armaException);
/*     */     }
/*     */     catch (ARMAException e)
/*     */     {
/* 116 */       throw new IllegalArgumentException("Comparison function failure:", e);
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\netapp\asup\data\function\sort\ExpressionComparator.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */