/*     */ package com.netapp.asup.data.schema;
/*     */ 
/*     */ import com.netapp.asup.common.AsupLogger;
/*     */ import com.netapp.asup.config.ARMAConfiguration;
/*     */ import com.netapp.asup.data.util.HttpConnectionManager;
/*     */ import com.netapp.asup.data.util.HttpConnectionManager.HttpConnection;
/*     */ import com.netapp.asup.data.utils.Md5Util;
/*     */ import com.netapp.asup.exception.ARMAConfigurationException;
/*     */ import com.netapp.asup.exception.ARMAException;
/*     */ import java.io.BufferedReader;
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.io.InputStreamReader;
/*     */ import java.util.HashMap;
/*     */ import java.util.Map;
/*     */ import java.util.Set;
/*     */ import java.util.TreeSet;
/*     */ import java.util.concurrent.locks.Lock;
/*     */ import java.util.concurrent.locks.ReadWriteLock;
/*     */ import java.util.concurrent.locks.ReentrantReadWriteLock;
/*     */ import java.util.zip.ZipEntry;
/*     */ import java.util.zip.ZipInputStream;
/*     */ import org.apache.avro.Schema;
/*     */ import org.apache.avro.Schema.Parser;
/*     */ 
/*     */ 
/*     */ public class ClientSchemaHelper
/*     */   implements SchemaHelper
/*     */ {
/*     */   private static final String ALL_SCHMEA_LOADING = "ALL_SCHMEA_LOADING";
/*     */   private static final String SLASH_DELIMITER = "/";
/*     */   private static final String DEFAULT_SNAPSHOT_VERSION = "0.0.1-SNAPSHOT";
/*     */   private Map<String, Schema> activeSchema;
/*     */   private Map<String, Schema> latestSchema;
/*     */   private String allSchemaCrc;
/*  36 */   private static final AsupLogger LOGGER = AsupLogger.getLogger(ClientSchemaHelper.class);
/*     */   
/*     */   private static final String ACTIVE_SCHEMA_VERSION = "arma.avro.client.schema.active.version";
/*     */   
/*     */   private static final String LATEST_SCHEMA_VERSION = "arma.avro.client.schema.latest.version";
/*     */   
/*     */   private static final String ARMA_META_MODEL = "arma/latestschema";
/*     */   
/*     */   private final HttpConnectionManager manager;
/*     */   
/*     */   public ClientSchemaHelper(ARMAConfiguration config)
/*     */   {
/*     */     try
/*     */     {
/*  50 */       this.manager = HttpConnectionManager.getInstance();
/*     */       
/*  52 */       String activeVersion = config.getString("arma.avro.client.schema.active.version");
/*  53 */       String latestVersion = config.getString("arma.avro.client.schema.latest.version");
/*     */       
/*  55 */       if (LOGGER.isDebugEnabled()) {
/*  56 */         LOGGER.debug(null, "Active version from config : " + activeVersion + " latest version from config : " + latestVersion);
/*     */       }
/*     */       
/*  59 */       String snapShotVersion = "0.0.1-SNAPSHOT";
/*  60 */       if (latestVersion == null)
/*  61 */         latestVersion = snapShotVersion;
/*  62 */       if (activeVersion == null) {
/*  63 */         activeVersion = latestVersion;
/*     */       }
/*  65 */       reloadSchemas();
/*     */     }
/*     */     catch (ARMAException e) {
/*  68 */       throw new RuntimeException(e);
/*     */     }
/*     */   }
/*     */   
/*     */   public Map<String, Schema> loadSchemaFromServer() throws ARMAException
/*     */   {
/*  74 */     latestAvroSchemaMap = new HashMap();
/*  75 */     StringBuilder sb = new StringBuilder();
/*     */     
/*  77 */     InputStream inputStream = null;
/*  78 */     ZipInputStream zis = null;
/*     */     try {
/*  80 */       HttpConnectionManager.HttpConnection connection = this.manager.getConnection("latestschema", "arma/latestschema", "POST");
/*     */       
/*  82 */       inputStream = connection.getRequest("latestschema");
/*     */       
/*  84 */       zis = new ZipInputStream(inputStream);
/*     */       
/*  86 */       ZipEntry nextEntry = null;
/*  87 */       while ((nextEntry = zis.getNextEntry()) != null) {
/*  88 */         int read = 0;
/*  89 */         byte[] bytes = new byte['Ѐ'];
/*  90 */         sb = new StringBuilder();
/*     */         
/*  92 */         while ((read = zis.read(bytes)) != -1) {
/*  93 */           sb.append(new String(bytes, 0, read));
/*  94 */           bytes = new byte['Ѐ'];
/*     */         }
/*  96 */         Schema schema = new Schema.Parser().parse(sb.toString());
/*  97 */         latestAvroSchemaMap.put(nextEntry.getName(), schema);
/*     */         
/*  99 */         zis.closeEntry();
/*     */       }
/*     */       
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 116 */       return latestAvroSchemaMap;
/*     */     }
/*     */     catch (Exception e)
/*     */     {
/* 103 */       throw new ARMAException(LOGGER, "ALL_SCHMEA_LOADING", "Unable to load schemas from the server", e);
/*     */     }
/*     */     finally {
/*     */       try {
/* 107 */         if (zis != null) {
/* 108 */           zis.close();
/*     */         }
/*     */       } catch (IOException e) {
/* 111 */         LOGGER.warn("ALL_SCHMEA_LOADING", "Failed to close zip input stream", e);
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public String computeAllSchemaCRC()
/*     */   {
/* 121 */     StringBuilder sb = new StringBuilder();
/* 122 */     String allSchemaCrc = null;
/*     */     
/* 124 */     Map<String, String> latestSchemaMd5 = computeAndGetLatestSchemaMd5(this.latestSchema);
/* 125 */     Set<String> keySet = new TreeSet(latestSchemaMd5.keySet());
/* 126 */     for (String key : keySet) {
/* 127 */       sb.append((String)latestSchemaMd5.get(key));
/*     */     }
/*     */     try {
/* 130 */       allSchemaCrc = Md5Util.getMd5Value(sb.toString());
/*     */     } catch (Exception e) {
/* 132 */       e.printStackTrace();
/*     */     }
/*     */     
/* 135 */     return allSchemaCrc;
/*     */   }
/*     */   
/*     */ 
/*     */   public Map<String, String> computeAndGetLatestSchemaMd5(Map<String, Schema> latestAvroSchemaMap)
/*     */   {
/* 141 */     Map<String, String> latestSchemaMd5Map = new HashMap();
/*     */     
/* 143 */     Schema latestSchema = null;
/* 144 */     String md5Value = null;
/*     */     
/* 146 */     Set<String> avroEntities = latestAvroSchemaMap.keySet();
/* 147 */     for (String avroEntity : avroEntities) {
/* 148 */       latestSchema = (Schema)latestAvroSchemaMap.get(avroEntity);
/*     */       try {
/* 150 */         md5Value = Md5Util.getMd5Value(latestSchema);
/*     */       } catch (Exception e) {
/* 152 */         e.printStackTrace();
/*     */       }
/*     */       
/* 155 */       latestSchemaMd5Map.put(avroEntity, md5Value);
/*     */     }
/* 157 */     return latestSchemaMd5Map;
/*     */   }
/*     */   
/*     */   public Map<String, Schema> loadSchemaFromLocal(String versionFolder, InputStream is) throws ARMAConfigurationException
/*     */   {
/* 162 */     Map<String, Schema> objectSchemaMap = new HashMap();
/*     */     
/* 164 */     BufferedReader reader = new BufferedReader(new InputStreamReader(is));
/* 165 */     String schemaLine = null;
/*     */     
/* 167 */     InputStream schemaInputStream = null;
/*     */     try
/*     */     {
/* 170 */       while ((schemaLine = reader.readLine()) != null)
/*     */       {
/* 172 */         schemaInputStream = getClass().getResourceAsStream("/" + versionFolder + "/" + schemaLine);
/*     */         
/*     */ 
/*     */ 
/* 176 */         Schema.Parser parser = new Schema.Parser();
/* 177 */         objectSchemaMap.put(schemaLine, parser.parse(schemaInputStream));
/*     */         
/* 179 */         if (LOGGER.isDebugEnabled()) {
/* 180 */           LOGGER.debug(null, "Parsed client schema : /" + versionFolder + "/" + schemaLine);
/*     */         }
/*     */       }
/*     */     }
/*     */     catch (IOException e)
/*     */     {
/* 186 */       throw new ARMAConfigurationException(LOGGER, "Unable to initialize schema from input stream " + is.toString() + " caused by : " + e.getMessage(), e);
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/* 192 */     return objectSchemaMap;
/*     */   }
/*     */   
/*     */   public void reloadSchemas() throws ARMAException {
/* 196 */     Lock writeLock = this.lockObject.writeLock();
/* 197 */     writeLock.lock();
/*     */     try {
/* 199 */       this.latestSchema = loadSchemaFromServer();
/* 200 */       this.activeSchema = this.latestSchema;
/* 201 */       this.allSchemaCrc = computeAllSchemaCRC();
/*     */     } finally {
/* 203 */       writeLock.unlock();
/*     */     }
/*     */   }
/*     */   
/*     */   public String getAllSchemaCrc() {
/* 208 */     Lock readLock = this.lockObject.readLock();
/*     */     
/* 210 */     readLock.lock();
/*     */     try {
/* 212 */       return this.allSchemaCrc;
/*     */     } finally {
/* 214 */       readLock.unlock();
/*     */     }
/*     */   }
/*     */   
/*     */   public Schema getActiveSchema(String objectName) {
/* 219 */     Lock readLock = this.lockObject.readLock();
/*     */     
/* 221 */     readLock.lock();
/*     */     try {
/* 223 */       return (Schema)this.activeSchema.get(objectName);
/*     */     } finally {
/* 225 */       readLock.unlock();
/*     */     }
/*     */   }
/*     */   
/*     */   public Schema getLatestSchema(String objectName)
/*     */   {
/* 231 */     Lock readLock = this.lockObject.readLock();
/*     */     
/* 233 */     readLock.lock();
/*     */     try {
/* 235 */       return (Schema)this.latestSchema.get(objectName);
/*     */     } finally {
/* 237 */       readLock.unlock();
/*     */     }
/*     */   }
/*     */   
/*     */   public Schema getSchemaByVersion(String objectName, String version)
/*     */   {
/* 243 */     Lock readLock = this.lockObject.readLock();
/*     */     
/* 245 */     readLock.lock();
/*     */     try {
/* 247 */       return (Schema)this.latestSchema.get(objectName);
/*     */     } finally {
/* 249 */       readLock.unlock();
/*     */     }
/*     */   }
/*     */   
/*     */ 
/* 254 */   private ReadWriteLock lockObject = new ReentrantReadWriteLock();
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\com\netapp\asup\data\schema\ClientSchemaHelper.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */