/*     */ package com.sun.xml.bind.v2;
/*     */ 
/*     */ import com.sun.istack.FinalArrayList;
/*     */ import com.sun.xml.bind.api.TypeReference;
/*     */ import com.sun.xml.bind.v2.runtime.JAXBContextImpl;
/*     */ import java.io.BufferedReader;
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.io.InputStreamReader;
/*     */ import java.util.Collection;
/*     */ import java.util.Collections;
/*     */ import java.util.HashMap;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import java.util.Set;
/*     */ import java.util.StringTokenizer;
/*     */ import javax.xml.bind.JAXBContext;
/*     */ import javax.xml.bind.JAXBException;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class ContextFactory
/*     */ {
/*     */   public static final String USE_JAXB_PROPERTIES = "_useJAXBProperties";
/*     */   
/*     */   public static JAXBContext createContext(Class[] classes, Map<String, Object> properties)
/*     */     throws JAXBException
/*     */   {
/*  39 */     if (properties == null) {
/*  40 */       properties = Collections.emptyMap();
/*     */     } else {
/*  42 */       properties = new HashMap(properties);
/*     */     }
/*  44 */     String defaultNsUri = (String)getPropertyValue(properties, "com.sun.xml.bind.defaultNamespaceRemap", String.class);
/*     */     
/*  46 */     Boolean c14nSupport = (Boolean)getPropertyValue(properties, "com.sun.xml.bind.c14n", Boolean.class);
/*  47 */     if (c14nSupport == null) {
/*  48 */       c14nSupport = Boolean.valueOf(false);
/*     */     }
/*     */     
/*  51 */     if (!properties.isEmpty()) {
/*  52 */       throw new JAXBException(Messages.UNSUPPORTED_PROPERTY.format(new Object[] { properties.keySet().iterator().next() }));
/*     */     }
/*     */     
/*  55 */     return createContext(classes, Collections.emptyList(), defaultNsUri, c14nSupport.booleanValue());
/*     */   }
/*     */   
/*     */ 
/*     */   private static <T> T getPropertyValue(Map<String, Object> properties, String keyName, Class<T> type)
/*     */     throws JAXBException
/*     */   {
/*  62 */     Object o = properties.get(keyName);
/*  63 */     if (o == null) { return null;
/*     */     }
/*  65 */     properties.remove(keyName);
/*  66 */     if (!type.isInstance(o)) {
/*  67 */       throw new JAXBException(Messages.INVALID_PROPERTY_VALUE.format(new Object[] { keyName, o }));
/*     */     }
/*  69 */     return (T)type.cast(o);
/*     */   }
/*     */   
/*     */ 
/*     */   public static JAXBContext createContext(Class[] classes, Collection<TypeReference> typeRefs, String defaultNsUri, boolean c14nSupport)
/*     */     throws JAXBException
/*     */   {
/*  76 */     return new JAXBContextImpl(classes, typeRefs, defaultNsUri, c14nSupport);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public static JAXBContext createContext(String contextPath, ClassLoader classLoader, Map<String, Object> properties)
/*     */     throws JAXBException
/*     */   {
/*  84 */     FinalArrayList<Class> classes = new FinalArrayList();
/*  85 */     StringTokenizer tokens = new StringTokenizer(contextPath, ":");
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  92 */     while (tokens.hasMoreTokens()) { boolean foundJaxbIndex;
/*  93 */       boolean foundObjectFactory = foundJaxbIndex = 0;
/*  94 */       String pkg = tokens.nextToken();
/*     */       
/*     */ 
/*     */       try
/*     */       {
/*  99 */         Class<?> o = classLoader.loadClass(pkg + ".ObjectFactory");
/* 100 */         classes.add(o);
/* 101 */         foundObjectFactory = true;
/*     */       }
/*     */       catch (ClassNotFoundException e) {}
/*     */       
/*     */       List<Class> indexedClasses;
/*     */       try
/*     */       {
/* 108 */         indexedClasses = loadIndexedClasses(pkg, classLoader);
/*     */       }
/*     */       catch (IOException e) {
/* 111 */         throw new JAXBException(e);
/*     */       }
/* 113 */       if (indexedClasses != null) {
/* 114 */         classes.addAll(indexedClasses);
/* 115 */         foundJaxbIndex = true;
/*     */       }
/*     */       
/* 118 */       if ((!foundObjectFactory) && (!foundJaxbIndex)) {
/* 119 */         throw new JAXBException(Messages.BROKEN_CONTEXTPATH.format(new Object[] { pkg }));
/*     */       }
/*     */     }
/*     */     
/*     */ 
/* 124 */     return createContext((Class[])classes.toArray(new Class[classes.size()]), properties);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private static List<Class> loadIndexedClasses(String pkg, ClassLoader classLoader)
/*     */     throws IOException, JAXBException
/*     */   {
/* 137 */     String resource = pkg.replace('.', '/') + "/jaxb.index";
/* 138 */     InputStream resourceAsStream = classLoader.getResourceAsStream(resource);
/*     */     
/* 140 */     if (resourceAsStream == null) {
/* 141 */       return null;
/*     */     }
/*     */     
/* 144 */     BufferedReader in = new BufferedReader(new InputStreamReader(resourceAsStream, "UTF-8"));
/*     */     try
/*     */     {
/* 147 */       FinalArrayList<Class> classes = new FinalArrayList();
/* 148 */       String className = in.readLine();
/* 149 */       while (className != null) {
/* 150 */         className = className.trim();
/* 151 */         if ((className.startsWith("#")) || (className.length() == 0)) {
/* 152 */           className = in.readLine();
/*     */         }
/*     */         else
/*     */         {
/* 156 */           if (className.endsWith(".class")) {
/* 157 */             throw new JAXBException(Messages.ILLEGAL_ENTRY.format(new Object[] { className }));
/*     */           }
/*     */           try
/*     */           {
/* 161 */             classes.add(classLoader.loadClass(pkg + '.' + className));
/*     */           } catch (ClassNotFoundException e) {
/* 163 */             throw new JAXBException(Messages.ERROR_LOADING_CLASS.format(new Object[] { className, resource }), e);
/*     */           }
/*     */           
/* 166 */           className = in.readLine();
/*     */         } }
/* 168 */       return classes;
/*     */     } finally {
/* 170 */       in.close();
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\target\myautosupport\WEB-INF\lib\jaxb-impl-2.0.3.jar!\com\sun\xml\bind\v2\ContextFactory.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */