/*     */ package net.rubyeye.xmemcached;
/*     */ 
/*     */ import com.google.code.yanf4j.config.Configuration;
/*     */ import com.google.code.yanf4j.core.SocketOption;
/*     */ import com.google.code.yanf4j.core.impl.StandardSocketOption;
/*     */ import java.io.IOException;
/*     */ import java.net.InetSocketAddress;
/*     */ import java.util.ArrayList;
/*     */ import java.util.HashMap;
/*     */ import java.util.LinkedHashMap;
/*     */ import java.util.List;
/*     */ import java.util.Map;
/*     */ import net.rubyeye.xmemcached.auth.AuthInfo;
/*     */ import net.rubyeye.xmemcached.buffer.BufferAllocator;
/*     */ import net.rubyeye.xmemcached.buffer.SimpleBufferAllocator;
/*     */ import net.rubyeye.xmemcached.command.TextCommandFactory;
/*     */ import net.rubyeye.xmemcached.impl.ArrayMemcachedSessionLocator;
/*     */ import net.rubyeye.xmemcached.impl.DefaultKeyProvider;
/*     */ import net.rubyeye.xmemcached.transcoders.SerializingTranscoder;
/*     */ import net.rubyeye.xmemcached.transcoders.Transcoder;
/*     */ import net.rubyeye.xmemcached.utils.Protocol;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class XMemcachedClientBuilder
/*     */   implements MemcachedClientBuilder
/*     */ {
/*  33 */   private MemcachedSessionLocator sessionLocator = new ArrayMemcachedSessionLocator();
/*  34 */   private BufferAllocator bufferAllocator = new SimpleBufferAllocator();
/*  35 */   private Configuration configuration = getDefaultConfiguration();
/*  36 */   private Map<InetSocketAddress, InetSocketAddress> addressMap = new LinkedHashMap();
/*     */   
/*     */   private int[] weights;
/*     */   
/*  40 */   private long connectTimeout = 60000L;
/*     */   
/*  42 */   private int connectionPoolSize = 1;
/*     */   
/*  44 */   final Map<SocketOption, Object> socketOptions = getDefaultSocketOptions();
/*     */   
/*     */ 
/*  47 */   private List<MemcachedClientStateListener> stateListeners = new ArrayList();
/*     */   
/*  49 */   private Map<InetSocketAddress, AuthInfo> authInfoMap = new HashMap();
/*     */   
/*     */   private String name;
/*     */   
/*     */   private boolean failureMode;
/*     */   
/*     */   private boolean sanitizeKeys;
/*     */   
/*  57 */   private KeyProvider keyProvider = DefaultKeyProvider.INSTANCE;
/*     */   
/*  59 */   private int maxQueuedNoReplyOperations = MemcachedClient.DEFAULT_MAX_QUEUED_NOPS;
/*     */   
/*     */   public int getMaxQueuedNoReplyOperations() {
/*  62 */     return this.maxQueuedNoReplyOperations;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void setMaxQueuedNoReplyOperations(int maxQueuedNoReplyOperations)
/*     */   {
/*  73 */     this.maxQueuedNoReplyOperations = maxQueuedNoReplyOperations;
/*     */   }
/*     */   
/*     */   public void setSanitizeKeys(boolean sanitizeKeys) {
/*  77 */     this.sanitizeKeys = sanitizeKeys;
/*     */   }
/*     */   
/*     */   public void addStateListener(MemcachedClientStateListener stateListener) {
/*  81 */     this.stateListeners.add(stateListener);
/*     */   }
/*     */   
/*     */   public void setSocketOption(SocketOption socketOption, Object value)
/*     */   {
/*  86 */     if (socketOption == null) {
/*  87 */       throw new NullPointerException("Null socketOption");
/*     */     }
/*  89 */     if (value == null) {
/*  90 */       throw new NullPointerException("Null value");
/*     */     }
/*  92 */     if (!socketOption.type().equals(value.getClass())) {
/*  93 */       throw new IllegalArgumentException("Expected " + socketOption.type().getSimpleName() + " value,but givend " + value.getClass().getSimpleName());
/*     */     }
/*     */     
/*     */ 
/*  97 */     this.socketOptions.put(socketOption, value);
/*     */   }
/*     */   
/*     */   public Map<SocketOption, Object> getSocketOptions()
/*     */   {
/* 102 */     return this.socketOptions;
/*     */   }
/*     */   
/*     */   public final void setConnectionPoolSize(int poolSize) {
/* 106 */     if (this.connectionPoolSize <= 0) {
/* 107 */       throw new IllegalArgumentException("poolSize<=0");
/*     */     }
/* 109 */     this.connectionPoolSize = poolSize;
/*     */   }
/*     */   
/*     */   public void removeStateListener(MemcachedClientStateListener stateListener) {
/* 113 */     this.stateListeners.remove(stateListener);
/*     */   }
/*     */   
/*     */   public long getConnectTimeout() {
/* 117 */     return this.connectTimeout;
/*     */   }
/*     */   
/*     */   public void setConnectTimeout(long connectTimeout) {
/* 121 */     this.connectTimeout = connectTimeout;
/*     */   }
/*     */   
/*     */   public void setStateListeners(List<MemcachedClientStateListener> stateListeners)
/*     */   {
/* 126 */     if (stateListeners == null) {
/* 127 */       throw new IllegalArgumentException("Null state listeners");
/*     */     }
/* 129 */     this.stateListeners = stateListeners;
/*     */   }
/*     */   
/* 132 */   private CommandFactory commandFactory = new TextCommandFactory();
/*     */   
/*     */   public static final Map<SocketOption, Object> getDefaultSocketOptions()
/*     */   {
/* 136 */     Map<SocketOption, Object> map = new HashMap();
/* 137 */     map.put(StandardSocketOption.TCP_NODELAY, Boolean.valueOf(true));
/*     */     
/* 139 */     map.put(StandardSocketOption.SO_RCVBUF, Integer.valueOf(65536));
/*     */     
/* 141 */     map.put(StandardSocketOption.SO_KEEPALIVE, Boolean.valueOf(true));
/*     */     
/* 143 */     map.put(StandardSocketOption.SO_SNDBUF, Integer.valueOf(32768));
/*     */     
/* 145 */     map.put(StandardSocketOption.SO_LINGER, Integer.valueOf(0));
/* 146 */     map.put(StandardSocketOption.SO_REUSEADDR, Boolean.valueOf(true));
/* 147 */     return map;
/*     */   }
/*     */   
/*     */   public static final Configuration getDefaultConfiguration() {
/* 151 */     Configuration configuration = new Configuration();
/* 152 */     configuration.setSessionReadBufferSize(131072);
/*     */     
/* 154 */     configuration.setReadThreadCount(0);
/*     */     
/* 156 */     configuration.setSessionIdleTimeout(5000L);
/*     */     
/* 158 */     configuration.setWriteThreadCount(0);
/* 159 */     return configuration;
/*     */   }
/*     */   
/*     */   public boolean isFailureMode() {
/* 163 */     return this.failureMode;
/*     */   }
/*     */   
/*     */   public void setFailureMode(boolean failureMode) {
/* 167 */     this.failureMode = failureMode;
/*     */   }
/*     */   
/*     */   public final CommandFactory getCommandFactory() {
/* 171 */     return this.commandFactory;
/*     */   }
/*     */   
/*     */   public final void setCommandFactory(CommandFactory commandFactory) {
/* 175 */     this.commandFactory = commandFactory;
/*     */   }
/*     */   
/* 178 */   private Transcoder transcoder = new SerializingTranscoder();
/*     */   
/*     */   public XMemcachedClientBuilder(List<InetSocketAddress> addressList)
/*     */   {
/* 182 */     if (addressList != null) {
/* 183 */       for (InetSocketAddress addr : addressList) {
/* 184 */         this.addressMap.put(addr, null);
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */   public XMemcachedClientBuilder(List<InetSocketAddress> addressList, int[] weights)
/*     */   {
/* 191 */     if (addressList != null) {
/* 192 */       for (InetSocketAddress addr : addressList) {
/* 193 */         this.addressMap.put(addr, null);
/*     */       }
/*     */     }
/* 196 */     this.weights = weights;
/*     */   }
/*     */   
/*     */   public XMemcachedClientBuilder(Map<InetSocketAddress, InetSocketAddress> addressMap)
/*     */   {
/* 201 */     this.addressMap = addressMap;
/*     */   }
/*     */   
/*     */   public XMemcachedClientBuilder(Map<InetSocketAddress, InetSocketAddress> addressMap, int[] weights)
/*     */   {
/* 206 */     this.addressMap = addressMap;
/* 207 */     this.weights = weights;
/*     */   }
/*     */   
/*     */   public XMemcachedClientBuilder() {
/* 211 */     this((Map)null);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public MemcachedSessionLocator getSessionLocator()
/*     */   {
/* 220 */     return this.sessionLocator;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void setSessionLocator(MemcachedSessionLocator sessionLocator)
/*     */   {
/* 231 */     if (sessionLocator == null) {
/* 232 */       throw new IllegalArgumentException("Null SessionLocator");
/*     */     }
/* 234 */     this.sessionLocator = sessionLocator;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public BufferAllocator getBufferAllocator()
/*     */   {
/* 243 */     return this.bufferAllocator;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void setBufferAllocator(BufferAllocator bufferAllocator)
/*     */   {
/* 254 */     if (bufferAllocator == null) {
/* 255 */       throw new IllegalArgumentException("Null bufferAllocator");
/*     */     }
/* 257 */     this.bufferAllocator = bufferAllocator;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public Configuration getConfiguration()
/*     */   {
/* 266 */     return this.configuration;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void setConfiguration(Configuration configuration)
/*     */   {
/* 277 */     this.configuration = configuration;
/*     */   }
/*     */   
/*     */ 
/*     */   public MemcachedClient build()
/*     */     throws IOException
/*     */   {
/*     */     XMemcachedClient memcachedClient;
/*     */     
/*     */     XMemcachedClient memcachedClient;
/* 287 */     if (this.weights == null) {
/* 288 */       memcachedClient = new XMemcachedClient(this.sessionLocator, this.bufferAllocator, this.configuration, this.socketOptions, this.commandFactory, this.transcoder, this.addressMap, this.stateListeners, this.authInfoMap, this.connectionPoolSize, this.connectTimeout, this.name, this.failureMode);
/*     */ 
/*     */ 
/*     */     }
/*     */     else
/*     */     {
/*     */ 
/*     */ 
/* 296 */       if (this.addressMap == null) {
/* 297 */         throw new IllegalArgumentException("Null Address map");
/*     */       }
/* 299 */       if (this.addressMap.size() > this.weights.length) {
/* 300 */         throw new IllegalArgumentException("Weights Array's length is less than server's number");
/*     */       }
/*     */       
/* 303 */       memcachedClient = new XMemcachedClient(this.sessionLocator, this.bufferAllocator, this.configuration, this.socketOptions, this.commandFactory, this.transcoder, this.addressMap, this.weights, this.stateListeners, this.authInfoMap, this.connectionPoolSize, this.connectTimeout, this.name, this.failureMode);
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 310 */     if (this.commandFactory.getProtocol() == Protocol.Kestrel) {
/* 311 */       memcachedClient.setOptimizeGet(false);
/*     */     }
/* 313 */     memcachedClient.setSanitizeKeys(this.sanitizeKeys);
/* 314 */     memcachedClient.setKeyProvider(this.keyProvider);
/* 315 */     memcachedClient.setMaxQueuedNoReplyOperations(this.maxQueuedNoReplyOperations);
/*     */     
/* 317 */     return memcachedClient;
/*     */   }
/*     */   
/*     */   public Transcoder getTranscoder()
/*     */   {
/* 322 */     return this.transcoder;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void setTranscoder(Transcoder transcoder)
/*     */   {
/* 332 */     if (transcoder == null) {
/* 333 */       throw new IllegalArgumentException("Null Transcoder");
/*     */     }
/* 335 */     this.transcoder = transcoder;
/*     */   }
/*     */   
/*     */   public Map<InetSocketAddress, AuthInfo> getAuthInfoMap() {
/* 339 */     return this.authInfoMap;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void setKeyProvider(KeyProvider keyProvider)
/*     */   {
/* 348 */     if (keyProvider == null)
/* 349 */       throw new IllegalArgumentException("null key provider");
/* 350 */     this.keyProvider = keyProvider;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void addAuthInfo(InetSocketAddress address, AuthInfo authInfo)
/*     */   {
/* 359 */     this.authInfoMap.put(address, authInfo);
/*     */   }
/*     */   
/*     */   public void removeAuthInfo(InetSocketAddress address) {
/* 363 */     this.authInfoMap.remove(address);
/*     */   }
/*     */   
/*     */   public void setAuthInfoMap(Map<InetSocketAddress, AuthInfo> authInfoMap) {
/* 367 */     this.authInfoMap = authInfoMap;
/*     */   }
/*     */   
/*     */   public String getName() {
/* 371 */     return this.name;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void setName(String name)
/*     */   {
/* 380 */     this.name = name;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\net\rubyeye\xmemcached\XMemcachedClientBuilder.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */