/*     */ package org.codehaus.jackson.map.ser;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.lang.reflect.Type;
/*     */ import org.codehaus.jackson.JsonGenerationException;
/*     */ import org.codehaus.jackson.JsonGenerator;
/*     */ import org.codehaus.jackson.JsonNode;
/*     */ import org.codehaus.jackson.map.JsonMappingException;
/*     */ import org.codehaus.jackson.map.JsonMappingException.Reference;
/*     */ import org.codehaus.jackson.map.JsonSerializer;
/*     */ import org.codehaus.jackson.map.ResolvableSerializer;
/*     */ import org.codehaus.jackson.map.SerializerProvider;
/*     */ import org.codehaus.jackson.map.TypeSerializer;
/*     */ import org.codehaus.jackson.node.ObjectNode;
/*     */ import org.codehaus.jackson.schema.JsonSchema;
/*     */ import org.codehaus.jackson.schema.SchemaAware;
/*     */ import org.codehaus.jackson.type.JavaType;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class BeanSerializer
/*     */   extends SerializerBase<Object>
/*     */   implements ResolvableSerializer, SchemaAware
/*     */ {
/*  30 */   protected static final BeanPropertyWriter[] NO_PROPS = new BeanPropertyWriter[0];
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected final BeanPropertyWriter[] _props;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected final BeanPropertyWriter[] _filteredProps;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected final AnyGetterWriter _anyGetterWriter;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected final Object _propertyFilterId;
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public BeanSerializer(JavaType type, BeanPropertyWriter[] properties, BeanPropertyWriter[] filteredProperties, AnyGetterWriter anyGetterWriter, Object filterId)
/*     */   {
/*  77 */     super(type);
/*  78 */     this._props = properties;
/*  79 */     this._filteredProps = filteredProperties;
/*  80 */     this._anyGetterWriter = anyGetterWriter;
/*  81 */     this._propertyFilterId = filterId;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public BeanSerializer(Class<?> rawType, BeanPropertyWriter[] properties, BeanPropertyWriter[] filteredProperties, AnyGetterWriter anyGetterWriter, Object filterId)
/*     */   {
/*  90 */     super(rawType);
/*  91 */     this._props = properties;
/*  92 */     this._filteredProps = filteredProperties;
/*  93 */     this._anyGetterWriter = anyGetterWriter;
/*  94 */     this._propertyFilterId = filterId;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected BeanSerializer(BeanSerializer src)
/*     */   {
/* 104 */     this(src._handledType, src._props, src._filteredProps, src._anyGetterWriter, src._propertyFilterId);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public static BeanSerializer createDummy(Class<?> forType)
/*     */   {
/* 120 */     return new BeanSerializer(forType, NO_PROPS, null, null, null);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final void serialize(Object bean, JsonGenerator jgen, SerializerProvider provider)
/*     */     throws IOException, JsonGenerationException
/*     */   {
/* 138 */     jgen.writeStartObject();
/* 139 */     if (this._propertyFilterId != null) {
/* 140 */       serializeFieldsFiltered(bean, jgen, provider);
/*     */     } else {
/* 142 */       serializeFields(bean, jgen, provider);
/*     */     }
/* 144 */     jgen.writeEndObject();
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public void serializeWithType(Object bean, JsonGenerator jgen, SerializerProvider provider, TypeSerializer typeSer)
/*     */     throws IOException, JsonGenerationException
/*     */   {
/* 152 */     typeSer.writeTypePrefixForObject(bean, jgen);
/* 153 */     if (this._propertyFilterId != null) {
/* 154 */       serializeFieldsFiltered(bean, jgen, provider);
/*     */     } else {
/* 156 */       serializeFields(bean, jgen, provider);
/*     */     }
/* 158 */     typeSer.writeTypeSuffixForObject(bean, jgen);
/*     */   }
/*     */   
/*     */   protected void serializeFields(Object bean, JsonGenerator jgen, SerializerProvider provider) throws IOException, JsonGenerationException
/*     */   {
/*     */     BeanPropertyWriter[] props;
/*     */     BeanPropertyWriter[] props;
/* 165 */     if ((this._filteredProps != null) && (provider.getSerializationView() != null)) {
/* 166 */       props = this._filteredProps;
/*     */     } else {
/* 168 */       props = this._props;
/*     */     }
/* 170 */     int i = 0;
/*     */     try {
/* 172 */       for (int len = props.length; i < len; i++) {
/* 173 */         BeanPropertyWriter prop = props[i];
/* 174 */         if (prop != null) {
/* 175 */           prop.serializeAsField(bean, jgen, provider);
/*     */         }
/*     */       }
/* 178 */       if (this._anyGetterWriter != null) {
/* 179 */         this._anyGetterWriter.getAndSerialize(bean, jgen, provider);
/*     */       }
/*     */     } catch (Exception e) {
/* 182 */       String name = i == props.length ? "[anySetter]" : props[i].getName();
/* 183 */       wrapAndThrow(provider, e, bean, name);
/*     */ 
/*     */     }
/*     */     catch (StackOverflowError e)
/*     */     {
/*     */ 
/* 189 */       JsonMappingException mapE = new JsonMappingException("Infinite recursion (StackOverflowError)");
/* 190 */       String name = i == props.length ? "[anySetter]" : props[i].getName();
/* 191 */       mapE.prependPath(new JsonMappingException.Reference(bean, name));
/* 192 */       throw mapE;
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected void serializeFieldsFiltered(Object bean, JsonGenerator jgen, SerializerProvider provider)
/*     */     throws IOException, JsonGenerationException
/*     */   {
/*     */     BeanPropertyWriter[] props;
/*     */     
/*     */ 
/*     */ 
/*     */     BeanPropertyWriter[] props;
/*     */     
/*     */ 
/*     */ 
/* 211 */     if ((this._filteredProps != null) && (provider.getSerializationView() != null)) {
/* 212 */       props = this._filteredProps;
/*     */     } else {
/* 214 */       props = this._props;
/*     */     }
/* 216 */     BeanPropertyFilter filter = findFilter(provider);
/* 217 */     int i = 0;
/*     */     try {
/* 219 */       for (int len = props.length; i < len; i++) {
/* 220 */         BeanPropertyWriter prop = props[i];
/* 221 */         if (prop != null) {
/* 222 */           filter.serializeAsField(bean, jgen, provider, prop);
/*     */         }
/*     */       }
/* 225 */       if (this._anyGetterWriter != null) {
/* 226 */         this._anyGetterWriter.getAndSerialize(bean, jgen, provider);
/*     */       }
/*     */     } catch (Exception e) {
/* 229 */       String name = i == props.length ? "[anySetter]" : props[i].getName();
/* 230 */       wrapAndThrow(provider, e, bean, name);
/*     */     } catch (StackOverflowError e) {
/* 232 */       JsonMappingException mapE = new JsonMappingException("Infinite recursion (StackOverflowError)");
/* 233 */       String name = i == props.length ? "[anySetter]" : props[i].getName();
/* 234 */       mapE.prependPath(new JsonMappingException.Reference(bean, name));
/* 235 */       throw mapE;
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected BeanPropertyFilter findFilter(SerializerProvider provider)
/*     */     throws JsonMappingException
/*     */   {
/* 248 */     Object filterId = this._propertyFilterId;
/* 249 */     FilterProvider filters = provider.getFilterProvider();
/*     */     
/* 251 */     if (filters == null) {
/* 252 */       throw new JsonMappingException("Can not resolve BeanPropertyFilter with id '" + filterId + "'; no FilterProvider configured");
/*     */     }
/* 254 */     BeanPropertyFilter filter = filters.findFilter(filterId);
/*     */     
/* 256 */     if (filter == null) {
/* 257 */       throw new JsonMappingException("No filter configured with id '" + filterId + "' (type " + filterId.getClass().getName() + ")");
/*     */     }
/*     */     
/* 260 */     return filter;
/*     */   }
/*     */   
/*     */ 
/*     */   public JsonNode getSchema(SerializerProvider provider, Type typeHint)
/*     */     throws JsonMappingException
/*     */   {
/* 267 */     ObjectNode o = createSchemaNode("object", true);
/*     */     
/*     */ 
/* 270 */     ObjectNode propertiesNode = o.objectNode();
/* 271 */     for (int i = 0; i < this._props.length; i++) {
/* 272 */       BeanPropertyWriter prop = this._props[i];
/* 273 */       JavaType propType = prop.getSerializationType();
/*     */       
/* 275 */       Type hint = propType == null ? prop.getGenericPropertyType() : propType.getRawClass();
/*     */       
/* 277 */       JsonSerializer<Object> ser = prop.getSerializer();
/* 278 */       if (ser == null) {
/* 279 */         Class<?> serType = prop.getRawSerializationType();
/* 280 */         if (serType == null) {
/* 281 */           serType = prop.getPropertyType();
/*     */         }
/* 283 */         ser = provider.findValueSerializer(serType, prop);
/*     */       }
/* 285 */       JsonNode schemaNode = (ser instanceof SchemaAware) ? ((SchemaAware)ser).getSchema(provider, hint) : JsonSchema.getDefaultSchemaNode();
/*     */       
/*     */ 
/* 288 */       propertiesNode.put(prop.getName(), schemaNode);
/*     */     }
/* 290 */     o.put("properties", propertiesNode);
/* 291 */     return o;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void resolve(SerializerProvider provider)
/*     */     throws JsonMappingException
/*     */   {
/* 305 */     int filteredCount = this._filteredProps == null ? 0 : this._filteredProps.length;
/* 306 */     int i = 0; for (int len = this._props.length; i < len; i++) {
/* 307 */       BeanPropertyWriter prop = this._props[i];
/* 308 */       if (!prop.hasSerializer())
/*     */       {
/*     */ 
/*     */ 
/* 312 */         JavaType type = prop.getSerializationType();
/*     */         
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 318 */         if (type == null) {
/* 319 */           type = provider.constructType(prop.getGenericPropertyType());
/* 320 */           if (!type.isFinal())
/*     */           {
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 326 */             if ((!type.isContainerType()) && (type.containedTypeCount() <= 0)) continue;
/* 327 */             prop.setNonTrivialBaseType(type); continue;
/*     */           }
/*     */         }
/*     */         
/*     */ 
/* 332 */         JsonSerializer<Object> ser = provider.findValueSerializer(type, prop);
/*     */         
/*     */ 
/*     */ 
/* 336 */         if (type.isContainerType()) {
/* 337 */           TypeSerializer typeSer = (TypeSerializer)type.getContentType().getTypeHandler();
/* 338 */           if (typeSer != null)
/*     */           {
/* 340 */             if ((ser instanceof ContainerSerializerBase))
/*     */             {
/*     */ 
/* 343 */               JsonSerializer<Object> ser2 = ((ContainerSerializerBase)ser).withValueTypeSerializer(typeSer);
/* 344 */               ser = ser2;
/*     */             }
/*     */           }
/*     */         }
/* 348 */         prop = prop.withSerializer(ser);
/* 349 */         this._props[i] = prop;
/*     */         
/* 351 */         if (i < filteredCount) {
/* 352 */           BeanPropertyWriter w2 = this._filteredProps[i];
/* 353 */           if (w2 != null) {
/* 354 */             this._filteredProps[i] = w2.withSerializer(ser);
/*     */           }
/*     */         }
/*     */       }
/*     */     }
/*     */     
/* 360 */     if (this._anyGetterWriter != null) {
/* 361 */       this._anyGetterWriter.resolve(provider);
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public String toString()
/*     */   {
/* 372 */     return "BeanSerializer for " + handledType().getName();
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\codehaus\jackson\map\ser\BeanSerializer.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */