/*     */ package org.codehaus.jackson.node;
/*     */ 
/*     */ import java.math.BigDecimal;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Collection;
/*     */ import java.util.List;
/*     */ import org.codehaus.jackson.JsonGenerator;
/*     */ import org.codehaus.jackson.JsonNode;
/*     */ import org.codehaus.jackson.JsonToken;
/*     */ import org.codehaus.jackson.map.SerializerProvider;
/*     */ import org.codehaus.jackson.map.TypeSerializer;
/*     */ 
/*     */ public final class ArrayNode extends ContainerNode
/*     */ {
/*     */   protected ArrayList<JsonNode> _children;
/*     */   
/*     */   public ArrayNode(JsonNodeFactory nc)
/*     */   {
/*  19 */     super(nc);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public JsonToken asToken()
/*     */   {
/*  27 */     return JsonToken.START_ARRAY;
/*     */   }
/*     */   
/*  30 */   public boolean isArray() { return true; }
/*     */   
/*     */ 
/*     */   public int size()
/*     */   {
/*  35 */     return this._children == null ? 0 : this._children.size();
/*     */   }
/*     */   
/*     */ 
/*     */   public java.util.Iterator<JsonNode> getElements()
/*     */   {
/*  41 */     return this._children == null ? ContainerNode.NoNodesIterator.instance() : this._children.iterator();
/*     */   }
/*     */   
/*     */ 
/*     */   public JsonNode get(int index)
/*     */   {
/*  47 */     if ((index >= 0) && (this._children != null) && (index < this._children.size())) {
/*  48 */       return (JsonNode)this._children.get(index);
/*     */     }
/*  50 */     return null;
/*     */   }
/*     */   
/*     */   public JsonNode get(String fieldName) {
/*  54 */     return null;
/*     */   }
/*     */   
/*  57 */   public JsonNode path(String fieldName) { return MissingNode.getInstance(); }
/*     */   
/*     */ 
/*     */   public JsonNode path(int index)
/*     */   {
/*  62 */     if ((index >= 0) && (this._children != null) && (index < this._children.size())) {
/*  63 */       return (JsonNode)this._children.get(index);
/*     */     }
/*  65 */     return MissingNode.getInstance();
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public final void serialize(JsonGenerator jg, SerializerProvider provider)
/*     */     throws java.io.IOException, org.codehaus.jackson.JsonProcessingException
/*     */   {
/*  78 */     jg.writeStartArray();
/*  79 */     if (this._children != null) {
/*  80 */       for (JsonNode n : this._children)
/*     */       {
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  86 */         ((BaseJsonNode)n).writeTo(jg);
/*     */       }
/*     */     }
/*  89 */     jg.writeEndArray();
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public void serializeWithType(JsonGenerator jg, SerializerProvider provider, TypeSerializer typeSer)
/*     */     throws java.io.IOException, org.codehaus.jackson.JsonProcessingException
/*     */   {
/*  97 */     typeSer.writeTypePrefixForArray(this, jg);
/*  98 */     if (this._children != null) {
/*  99 */       for (JsonNode n : this._children) {
/* 100 */         ((BaseJsonNode)n).writeTo(jg);
/*     */       }
/*     */     }
/* 103 */     typeSer.writeTypeSuffixForArray(this, jg);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public JsonNode findValue(String fieldName)
/*     */   {
/* 115 */     if (this._children != null) {
/* 116 */       for (JsonNode node : this._children) {
/* 117 */         JsonNode value = node.findValue(fieldName);
/* 118 */         if (value != null) {
/* 119 */           return value;
/*     */         }
/*     */       }
/*     */     }
/* 123 */     return null;
/*     */   }
/*     */   
/*     */ 
/*     */   public List<JsonNode> findValues(String fieldName, List<JsonNode> foundSoFar)
/*     */   {
/* 129 */     if (this._children != null) {
/* 130 */       for (JsonNode node : this._children) {
/* 131 */         foundSoFar = node.findValues(fieldName, foundSoFar);
/*     */       }
/*     */     }
/* 134 */     return foundSoFar;
/*     */   }
/*     */   
/*     */ 
/*     */   public List<String> findValuesAsText(String fieldName, List<String> foundSoFar)
/*     */   {
/* 140 */     if (this._children != null) {
/* 141 */       for (JsonNode node : this._children) {
/* 142 */         foundSoFar = node.findValuesAsText(fieldName, foundSoFar);
/*     */       }
/*     */     }
/* 145 */     return foundSoFar;
/*     */   }
/*     */   
/*     */ 
/*     */   public ObjectNode findParent(String fieldName)
/*     */   {
/* 151 */     if (this._children != null) {
/* 152 */       for (JsonNode node : this._children) {
/* 153 */         JsonNode parent = node.findParent(fieldName);
/* 154 */         if (parent != null) {
/* 155 */           return (ObjectNode)parent;
/*     */         }
/*     */       }
/*     */     }
/* 159 */     return null;
/*     */   }
/*     */   
/*     */ 
/*     */   public List<JsonNode> findParents(String fieldName, List<JsonNode> foundSoFar)
/*     */   {
/* 165 */     if (this._children != null) {
/* 166 */       for (JsonNode node : this._children) {
/* 167 */         foundSoFar = node.findParents(fieldName, foundSoFar);
/*     */       }
/*     */     }
/* 170 */     return foundSoFar;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public JsonNode set(int index, JsonNode value)
/*     */   {
/* 192 */     if (value == null) {
/* 193 */       value = nullNode();
/*     */     }
/* 195 */     return _set(index, value);
/*     */   }
/*     */   
/*     */   public void add(JsonNode value)
/*     */   {
/* 200 */     if (value == null) {
/* 201 */       value = nullNode();
/*     */     }
/* 203 */     _add(value);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public JsonNode addAll(ArrayNode other)
/*     */   {
/* 218 */     int len = other.size();
/* 219 */     if (len > 0) {
/* 220 */       if (this._children == null) {
/* 221 */         this._children = new ArrayList(len + 2);
/*     */       }
/* 223 */       other.addContentsTo(this._children);
/*     */     }
/* 225 */     return this;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public JsonNode addAll(Collection<JsonNode> nodes)
/*     */   {
/* 239 */     int len = nodes.size();
/* 240 */     if (len > 0) {
/* 241 */       if (this._children == null) {
/* 242 */         this._children = new ArrayList(nodes);
/*     */       } else {
/* 244 */         this._children.addAll(nodes);
/*     */       }
/*     */     }
/* 247 */     return this;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void insert(int index, JsonNode value)
/*     */   {
/* 259 */     if (value == null) {
/* 260 */       value = nullNode();
/*     */     }
/* 262 */     _insert(index, value);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public JsonNode remove(int index)
/*     */   {
/* 272 */     if ((index >= 0) && (this._children != null) && (index < this._children.size())) {
/* 273 */       return (JsonNode)this._children.remove(index);
/*     */     }
/* 275 */     return null;
/*     */   }
/*     */   
/*     */ 
/*     */   public ArrayNode removeAll()
/*     */   {
/* 281 */     this._children = null;
/* 282 */     return this;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public ArrayNode addArray()
/*     */   {
/* 299 */     ArrayNode n = arrayNode();
/* 300 */     _add(n);
/* 301 */     return n;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public ObjectNode addObject()
/*     */   {
/* 312 */     ObjectNode n = objectNode();
/* 313 */     _add(n);
/* 314 */     return n;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void addPOJO(Object value)
/*     */   {
/* 323 */     if (value == null) {
/* 324 */       addNull();
/*     */     } else {
/* 326 */       _add(POJONode(value));
/*     */     }
/*     */   }
/*     */   
/*     */   public void addNull()
/*     */   {
/* 332 */     _add(nullNode());
/*     */   }
/*     */   
/*     */ 
/*     */   public void add(int v)
/*     */   {
/* 338 */     _add(numberNode(v));
/*     */   }
/*     */   
/*     */   public void add(long v)
/*     */   {
/* 343 */     _add(numberNode(v));
/*     */   }
/*     */   
/*     */   public void add(float v)
/*     */   {
/* 348 */     _add(numberNode(v));
/*     */   }
/*     */   
/*     */   public void add(double v)
/*     */   {
/* 353 */     _add(numberNode(v));
/*     */   }
/*     */   
/*     */ 
/*     */   public void add(BigDecimal v)
/*     */   {
/* 359 */     if (v == null) {
/* 360 */       addNull();
/*     */     } else {
/* 362 */       _add(numberNode(v));
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public void add(String v)
/*     */   {
/* 370 */     if (v == null) {
/* 371 */       addNull();
/*     */     } else {
/* 373 */       _add(textNode(v));
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */   public void add(boolean v)
/*     */   {
/* 380 */     _add(booleanNode(v));
/*     */   }
/*     */   
/*     */ 
/*     */   public void add(byte[] v)
/*     */   {
/* 386 */     if (v == null) {
/* 387 */       addNull();
/*     */     } else {
/* 389 */       _add(binaryNode(v));
/*     */     }
/*     */   }
/*     */   
/*     */   public ArrayNode insertArray(int index)
/*     */   {
/* 395 */     ArrayNode n = arrayNode();
/* 396 */     _insert(index, n);
/* 397 */     return n;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public ObjectNode insertObject(int index)
/*     */   {
/* 408 */     ObjectNode n = objectNode();
/* 409 */     _insert(index, n);
/* 410 */     return n;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void insertPOJO(int index, Object value)
/*     */   {
/* 419 */     if (value == null) {
/* 420 */       insertNull(index);
/*     */     } else {
/* 422 */       _insert(index, POJONode(value));
/*     */     }
/*     */   }
/*     */   
/*     */   public void insertNull(int index)
/*     */   {
/* 428 */     _insert(index, nullNode());
/*     */   }
/*     */   
/*     */ 
/*     */   public void insert(int index, int v)
/*     */   {
/* 434 */     _insert(index, numberNode(v));
/*     */   }
/*     */   
/*     */   public void insert(int index, long v)
/*     */   {
/* 439 */     _insert(index, numberNode(v));
/*     */   }
/*     */   
/*     */   public void insert(int index, float v)
/*     */   {
/* 444 */     _insert(index, numberNode(v));
/*     */   }
/*     */   
/*     */   public void insert(int index, double v)
/*     */   {
/* 449 */     _insert(index, numberNode(v));
/*     */   }
/*     */   
/*     */ 
/*     */   public void insert(int index, BigDecimal v)
/*     */   {
/* 455 */     if (v == null) {
/* 456 */       insertNull(index);
/*     */     } else {
/* 458 */       _insert(index, numberNode(v));
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public void insert(int index, String v)
/*     */   {
/* 466 */     if (v == null) {
/* 467 */       insertNull(index);
/*     */     } else {
/* 469 */       _insert(index, textNode(v));
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */   public void insert(int index, boolean v)
/*     */   {
/* 476 */     _insert(index, booleanNode(v));
/*     */   }
/*     */   
/*     */ 
/*     */   public void insert(int index, byte[] v)
/*     */   {
/* 482 */     if (v == null) {
/* 483 */       insertNull(index);
/*     */     } else {
/* 485 */       _insert(index, binaryNode(v));
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   protected void addContentsTo(List<JsonNode> dst)
/*     */   {
/* 500 */     if (this._children != null) {
/* 501 */       for (JsonNode n : this._children) {
/* 502 */         dst.add(n);
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public boolean equals(Object o)
/*     */   {
/* 516 */     if (o == this) return true;
/* 517 */     if (o == null) return false;
/* 518 */     if (o.getClass() != getClass()) {
/* 519 */       return false;
/*     */     }
/* 521 */     ArrayNode other = (ArrayNode)o;
/* 522 */     if ((this._children == null) || (this._children.size() == 0)) {
/* 523 */       return other.size() == 0;
/*     */     }
/* 525 */     return other._sameChildren(this._children);
/*     */   }
/*     */   
/*     */   public int hashCode()
/*     */   {
/*     */     int hash;
/*     */     int hash;
/* 532 */     if (this._children == null) {
/* 533 */       hash = 1;
/*     */     } else {
/* 535 */       hash = this._children.size();
/* 536 */       for (JsonNode n : this._children) {
/* 537 */         if (n != null) {
/* 538 */           hash ^= n.hashCode();
/*     */         }
/*     */       }
/*     */     }
/* 542 */     return hash;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public String toString()
/*     */   {
/* 549 */     StringBuilder sb = new StringBuilder(16 + (size() << 4));
/* 550 */     sb.append('[');
/* 551 */     if (this._children != null) {
/* 552 */       int i = 0; for (int len = this._children.size(); i < len; i++) {
/* 553 */         if (i > 0) {
/* 554 */           sb.append(',');
/*     */         }
/* 556 */         sb.append(((JsonNode)this._children.get(i)).toString());
/*     */       }
/*     */     }
/* 559 */     sb.append(']');
/* 560 */     return sb.toString();
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public JsonNode _set(int index, JsonNode value)
/*     */   {
/* 571 */     if ((this._children == null) || (index < 0) || (index >= this._children.size())) {
/* 572 */       throw new IndexOutOfBoundsException("Illegal index " + index + ", array size " + size());
/*     */     }
/* 574 */     return (JsonNode)this._children.set(index, value);
/*     */   }
/*     */   
/*     */   private void _add(JsonNode node)
/*     */   {
/* 579 */     if (this._children == null) {
/* 580 */       this._children = new ArrayList();
/*     */     }
/* 582 */     this._children.add(node);
/*     */   }
/*     */   
/*     */   private void _insert(int index, JsonNode node)
/*     */   {
/* 587 */     if (this._children == null) {
/* 588 */       this._children = new ArrayList();
/* 589 */       this._children.add(node);
/* 590 */       return;
/*     */     }
/* 592 */     if (index < 0) {
/* 593 */       this._children.add(0, node);
/* 594 */     } else if (index >= this._children.size()) {
/* 595 */       this._children.add(node);
/*     */     } else {
/* 597 */       this._children.add(index, node);
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private boolean _sameChildren(ArrayList<JsonNode> otherChildren)
/*     */   {
/* 607 */     int len = otherChildren.size();
/* 608 */     if (size() != len) {
/* 609 */       return false;
/*     */     }
/* 611 */     for (int i = 0; i < len; i++) {
/* 612 */       if (!((JsonNode)this._children.get(i)).equals(otherChildren.get(i))) {
/* 613 */         return false;
/*     */       }
/*     */     }
/* 616 */     return true;
/*     */   }
/*     */ }


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\org\codehaus\jackson\node\ArrayNode.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */