package prefuse.data.util;

import java.util.Comparator;
import prefuse.data.Table;
import prefuse.data.column.Column;
import prefuse.data.event.ColumnListener;
import prefuse.data.event.TableListener;
import prefuse.util.collections.BooleanIntSortedMap;
import prefuse.util.collections.DoubleIntSortedMap;
import prefuse.util.collections.FloatIntSortedMap;
import prefuse.util.collections.IncompatibleComparatorException;
import prefuse.util.collections.IntIntSortedMap;
import prefuse.util.collections.IntIterator;
import prefuse.util.collections.IntSortedMap;
import prefuse.util.collections.LongIntSortedMap;
import prefuse.util.collections.ObjectIntSortedMap;
import prefuse.util.collections.SortedMapFactory;

public class TreeIndex
  implements Index, ColumnListener, TableListener
{
  protected Table m_table;
  protected RowManager m_rows;
  protected Column m_col;
  protected IntSortedMap m_index;
  protected boolean m_reindex;
  protected int m_colidx;
  
  public TreeIndex(Table paramTable, RowManager paramRowManager, Column paramColumn, Comparator paramComparator)
    throws IncompatibleComparatorException
  {
    this.m_table = paramTable;
    this.m_rows = paramRowManager;
    this.m_col = paramColumn;
    this.m_index = SortedMapFactory.getMap(paramColumn.getColumnClass(), paramComparator, false);
    index();
    this.m_col.addColumnListener(this);
    this.m_table.addTableListener(this);
  }
  
  public void dispose()
  {
    this.m_col.removeColumnListener(this);
    this.m_table.removeTableListener(this);
  }
  
  public Comparator getComparator()
  {
    return this.m_index.comparator();
  }
  
  public int size()
  {
    return this.m_index.size();
  }
  
  private int getColumnIndex()
  {
    if (this.m_table.getColumn(this.m_colidx) != this.m_col) {
      this.m_colidx = this.m_table.getColumnNumber(this.m_col);
    }
    return this.m_colidx;
  }
  
  public void index()
  {
    this.m_index.clear();
    int i = getColumnIndex();
    this.m_colidx = i;
    IntIterator localIntIterator = this.m_rows.rows();
    Object localObject;
    int j;
    if ((this.m_index instanceof IntIntSortedMap))
    {
      localObject = (IntIntSortedMap)this.m_index;
      while (localIntIterator.hasNext())
      {
        j = localIntIterator.nextInt();
        ((IntIntSortedMap)localObject).put(this.m_col.getInt(this.m_table.getColumnRow(j, i)), j);
      }
    }
    else if ((this.m_index instanceof LongIntSortedMap))
    {
      localObject = (LongIntSortedMap)this.m_index;
      while (localIntIterator.hasNext())
      {
        j = localIntIterator.nextInt();
        ((LongIntSortedMap)localObject).put(this.m_col.getLong(this.m_table.getColumnRow(j, i)), j);
      }
    }
    else if ((this.m_index instanceof FloatIntSortedMap))
    {
      localObject = (FloatIntSortedMap)this.m_index;
      while (localIntIterator.hasNext())
      {
        j = localIntIterator.nextInt();
        ((FloatIntSortedMap)localObject).put(this.m_col.getFloat(this.m_table.getColumnRow(j, i)), j);
      }
    }
    else if ((this.m_index instanceof DoubleIntSortedMap))
    {
      localObject = (DoubleIntSortedMap)this.m_index;
      while (localIntIterator.hasNext())
      {
        j = localIntIterator.nextInt();
        ((DoubleIntSortedMap)localObject).put(this.m_col.getDouble(this.m_table.getColumnRow(j, i)), j);
      }
    }
    else if ((this.m_index instanceof BooleanIntSortedMap))
    {
      localObject = (BooleanIntSortedMap)this.m_index;
      while (localIntIterator.hasNext())
      {
        j = localIntIterator.nextInt();
        ((BooleanIntSortedMap)localObject).put(this.m_col.getBoolean(this.m_table.getColumnRow(j, i)), j);
      }
    }
    else if ((this.m_index instanceof ObjectIntSortedMap))
    {
      localObject = (ObjectIntSortedMap)this.m_index;
      while (localIntIterator.hasNext())
      {
        j = localIntIterator.nextInt();
        ((ObjectIntSortedMap)localObject).put(this.m_col.get(this.m_table.getColumnRow(j, i)), j);
      }
    }
    else
    {
      throw new IllegalStateException();
    }
    this.m_reindex = false;
  }
  
  public void tableChanged(Table paramTable, int paramInt1, int paramInt2, int paramInt3, int paramInt4)
  {
    if ((paramInt4 == 0) || (paramTable != this.m_table) || (paramInt3 != -1)) {
      return;
    }
    boolean bool = paramInt4 == 1;
    for (int i = paramInt1; i <= paramInt2; i++) {
      rowChanged(i, bool);
    }
  }
  
  private void rowChanged(int paramInt, boolean paramBoolean)
  {
    int i = this.m_rows.getColumnRow(paramInt, getColumnIndex());
    Object localObject1;
    if ((this.m_index instanceof IntIntSortedMap))
    {
      localObject1 = (IntIntSortedMap)this.m_index;
      int j = this.m_col.getInt(paramInt);
      if (paramBoolean) {
        ((IntIntSortedMap)localObject1).put(j, paramInt);
      } else {
        ((IntIntSortedMap)localObject1).remove(j, paramInt);
      }
    }
    else if ((this.m_index instanceof LongIntSortedMap))
    {
      localObject1 = (LongIntSortedMap)this.m_index;
      long l = this.m_col.getLong(i);
      if (paramBoolean) {
        ((LongIntSortedMap)localObject1).put(l, paramInt);
      } else {
        ((LongIntSortedMap)localObject1).remove(l, paramInt);
      }
    }
    else if ((this.m_index instanceof FloatIntSortedMap))
    {
      localObject1 = (FloatIntSortedMap)this.m_index;
      float f = this.m_col.getFloat(i);
      if (paramBoolean) {
        ((FloatIntSortedMap)localObject1).put(f, paramInt);
      } else {
        ((FloatIntSortedMap)localObject1).remove(f, paramInt);
      }
    }
    else if ((this.m_index instanceof DoubleIntSortedMap))
    {
      localObject1 = (DoubleIntSortedMap)this.m_index;
      double d = this.m_col.getDouble(i);
      if (paramBoolean) {
        ((DoubleIntSortedMap)localObject1).put(d, paramInt);
      } else {
        ((DoubleIntSortedMap)localObject1).remove(d, paramInt);
      }
    }
    else if ((this.m_index instanceof BooleanIntSortedMap))
    {
      localObject1 = (BooleanIntSortedMap)this.m_index;
      boolean bool = this.m_col.getBoolean(i);
      if (paramBoolean) {
        ((BooleanIntSortedMap)localObject1).put(bool, paramInt);
      } else {
        ((BooleanIntSortedMap)localObject1).remove(bool, paramInt);
      }
    }
    else if ((this.m_index instanceof ObjectIntSortedMap))
    {
      localObject1 = (ObjectIntSortedMap)this.m_index;
      Object localObject2 = this.m_col.get(i);
      if (paramBoolean) {
        ((ObjectIntSortedMap)localObject1).put(localObject2, paramInt);
      } else {
        ((ObjectIntSortedMap)localObject1).remove(localObject2, paramInt);
      }
    }
    else
    {
      throw new IllegalStateException();
    }
  }
  
  public void columnChanged(Column paramColumn, int paramInt1, int paramInt2, int paramInt3)
  {
    this.m_reindex = true;
  }
  
  public void columnChanged(Column paramColumn, int paramInt, boolean paramBoolean)
  {
    int i = this.m_rows.getTableRow(paramInt, getColumnIndex());
    if (i < 0) {
      return;
    }
    ((BooleanIntSortedMap)this.m_index).remove(paramBoolean, i);
    ((BooleanIntSortedMap)this.m_index).put(paramColumn.getBoolean(paramInt), i);
  }
  
  public void columnChanged(Column paramColumn, int paramInt1, int paramInt2)
  {
    int i = this.m_rows.getTableRow(paramInt1, getColumnIndex());
    if (i < 0) {
      return;
    }
    ((IntIntSortedMap)this.m_index).remove(paramInt2, i);
    ((IntIntSortedMap)this.m_index).put(paramColumn.getInt(paramInt1), i);
  }
  
  public void columnChanged(Column paramColumn, int paramInt, long paramLong)
  {
    int i = this.m_rows.getTableRow(paramInt, getColumnIndex());
    if (i < 0) {
      return;
    }
    ((LongIntSortedMap)this.m_index).remove(paramLong, i);
    ((LongIntSortedMap)this.m_index).put(paramColumn.getLong(paramInt), i);
  }
  
  public void columnChanged(Column paramColumn, int paramInt, float paramFloat)
  {
    int i = this.m_rows.getTableRow(paramInt, getColumnIndex());
    if (i < 0) {
      return;
    }
    ((FloatIntSortedMap)this.m_index).remove(paramFloat, i);
    ((FloatIntSortedMap)this.m_index).put(paramColumn.getFloat(paramInt), i);
  }
  
  public void columnChanged(Column paramColumn, int paramInt, double paramDouble)
  {
    int i = this.m_rows.getTableRow(paramInt, getColumnIndex());
    if (i < 0) {
      return;
    }
    ((DoubleIntSortedMap)this.m_index).remove(paramDouble, i);
    ((DoubleIntSortedMap)this.m_index).put(paramColumn.getDouble(paramInt), i);
  }
  
  public void columnChanged(Column paramColumn, int paramInt, Object paramObject)
  {
    int i = this.m_rows.getTableRow(paramInt, getColumnIndex());
    if (i < 0) {
      return;
    }
    ((ObjectIntSortedMap)this.m_index).remove(paramObject, i);
    ((ObjectIntSortedMap)this.m_index).put(paramColumn.get(paramInt), i);
  }
  
  public int minimum()
  {
    return this.m_index.getMinimum();
  }
  
  public int maximum()
  {
    return this.m_index.getMaximum();
  }
  
  public int median()
  {
    return this.m_index.getMedian();
  }
  
  public int uniqueCount()
  {
    return this.m_index.getUniqueCount();
  }
  
  public IntIterator allRows(int paramInt)
  {
    boolean bool = (paramInt & 0x20) > 0;
    return this.m_index.valueIterator(bool);
  }
  
  public IntIterator rows(Object paramObject1, Object paramObject2, int paramInt)
  {
    if (!(this.m_index instanceof ObjectIntSortedMap)) {
      throw new IllegalStateException();
    }
    int i = (paramInt & 0x10) > 0 ? 1 : 0;
    boolean bool1 = (paramInt & 0x8) > 0;
    boolean bool2 = (paramInt & 0x2) > 0;
    if (paramObject1 == null) {
      paramObject1 = ObjectIntSortedMap.MIN_KEY;
    }
    if (paramObject2 == null) {
      paramObject2 = ObjectIntSortedMap.MAX_KEY;
    }
    ObjectIntSortedMap localObjectIntSortedMap = (ObjectIntSortedMap)this.m_index;
    if (i != 0) {
      return localObjectIntSortedMap.valueRangeIterator(paramObject2, bool2, paramObject1, bool1);
    }
    return localObjectIntSortedMap.valueRangeIterator(paramObject1, bool1, paramObject2, bool2);
  }
  
  public IntIterator rows(int paramInt1, int paramInt2, int paramInt3)
  {
    if (!(this.m_index instanceof IntIntSortedMap)) {
      throw new IllegalStateException();
    }
    int i = (paramInt3 & 0x10) > 0 ? 1 : 0;
    boolean bool1 = (paramInt3 & 0x8) > 0;
    boolean bool2 = (paramInt3 & 0x2) > 0;
    IntIntSortedMap localIntIntSortedMap = (IntIntSortedMap)this.m_index;
    if (i != 0) {
      return localIntIntSortedMap.valueRangeIterator(paramInt2, bool2, paramInt1, bool1);
    }
    return localIntIntSortedMap.valueRangeIterator(paramInt1, bool1, paramInt2, bool2);
  }
  
  public IntIterator rows(long paramLong1, long paramLong2, int paramInt)
  {
    if (!(this.m_index instanceof LongIntSortedMap)) {
      throw new IllegalStateException();
    }
    int i = (paramInt & 0x10) > 0 ? 1 : 0;
    boolean bool1 = (paramInt & 0x8) > 0;
    boolean bool2 = (paramInt & 0x2) > 0;
    LongIntSortedMap localLongIntSortedMap = (LongIntSortedMap)this.m_index;
    if (i != 0) {
      return localLongIntSortedMap.valueRangeIterator(paramLong2, bool2, paramLong1, bool1);
    }
    return localLongIntSortedMap.valueRangeIterator(paramLong1, bool1, paramLong2, bool2);
  }
  
  public IntIterator rows(float paramFloat1, float paramFloat2, int paramInt)
  {
    if (!(this.m_index instanceof FloatIntSortedMap)) {
      throw new IllegalStateException();
    }
    int i = (paramInt & 0x10) > 0 ? 1 : 0;
    boolean bool1 = (paramInt & 0x8) > 0;
    boolean bool2 = (paramInt & 0x2) > 0;
    FloatIntSortedMap localFloatIntSortedMap = (FloatIntSortedMap)this.m_index;
    if (i != 0) {
      return localFloatIntSortedMap.valueRangeIterator(paramFloat2, bool2, paramFloat1, bool1);
    }
    return localFloatIntSortedMap.valueRangeIterator(paramFloat1, bool1, paramFloat2, bool2);
  }
  
  public IntIterator rows(double paramDouble1, double paramDouble2, int paramInt)
  {
    if (!(this.m_index instanceof DoubleIntSortedMap)) {
      throw new IllegalStateException();
    }
    int i = (paramInt & 0x10) > 0 ? 1 : 0;
    boolean bool1 = (paramInt & 0x8) > 0;
    boolean bool2 = (paramInt & 0x2) > 0;
    DoubleIntSortedMap localDoubleIntSortedMap = (DoubleIntSortedMap)this.m_index;
    if (i != 0) {
      return localDoubleIntSortedMap.valueRangeIterator(paramDouble2, bool2, paramDouble1, bool1);
    }
    return localDoubleIntSortedMap.valueRangeIterator(paramDouble1, bool1, paramDouble2, bool2);
  }
  
  public IntIterator rows(int paramInt)
  {
    return rows(paramInt, paramInt, 42);
  }
  
  public IntIterator rows(long paramLong)
  {
    return rows(paramLong, paramLong, 42);
  }
  
  public IntIterator rows(float paramFloat)
  {
    return rows(paramFloat, paramFloat, 42);
  }
  
  public IntIterator rows(double paramDouble)
  {
    return rows(paramDouble, paramDouble, 42);
  }
  
  public IntIterator rows(boolean paramBoolean)
  {
    if (!(this.m_index instanceof BooleanIntSortedMap)) {
      throw new IllegalStateException();
    }
    BooleanIntSortedMap localBooleanIntSortedMap = (BooleanIntSortedMap)this.m_index;
    return localBooleanIntSortedMap.valueRangeIterator(paramBoolean, true, paramBoolean, true);
  }
  
  public IntIterator rows(Object paramObject)
  {
    return rows(paramObject, paramObject, 42);
  }
  
  public int get(double paramDouble)
  {
    DoubleIntSortedMap localDoubleIntSortedMap = (DoubleIntSortedMap)this.m_index;
    return localDoubleIntSortedMap.get(paramDouble);
  }
  
  public int get(float paramFloat)
  {
    FloatIntSortedMap localFloatIntSortedMap = (FloatIntSortedMap)this.m_index;
    return localFloatIntSortedMap.get(paramFloat);
  }
  
  public int get(int paramInt)
  {
    IntIntSortedMap localIntIntSortedMap = (IntIntSortedMap)this.m_index;
    return localIntIntSortedMap.get(paramInt);
  }
  
  public int get(long paramLong)
  {
    LongIntSortedMap localLongIntSortedMap = (LongIntSortedMap)this.m_index;
    return localLongIntSortedMap.get(paramLong);
  }
  
  public int get(Object paramObject)
  {
    ObjectIntSortedMap localObjectIntSortedMap = (ObjectIntSortedMap)this.m_index;
    return localObjectIntSortedMap.get(paramObject);
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\data\util\TreeIndex.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */