package prefuse.util.collections;

public class DoubleIntTreeMap
  extends AbstractTreeMap
  implements DoubleIntSortedMap
{
  private DoubleEntry dummy = new DoubleEntry(Double.MIN_VALUE, Integer.MAX_VALUE, NIL, 0);
  
  public DoubleIntTreeMap()
  {
    this(null, false);
  }
  
  public DoubleIntTreeMap(boolean paramBoolean)
  {
    this(null, paramBoolean);
  }
  
  public DoubleIntTreeMap(LiteralComparator paramLiteralComparator)
  {
    this(paramLiteralComparator, false);
  }
  
  public DoubleIntTreeMap(LiteralComparator paramLiteralComparator, boolean paramBoolean)
  {
    super(paramLiteralComparator, paramBoolean);
  }
  
  public void clear()
  {
    this.modCount += 1;
    this.size = 0;
    this.root = NIL;
  }
  
  public boolean containsKey(double paramDouble)
  {
    return find(paramDouble, 0) != NIL;
  }
  
  public int get(double paramDouble)
  {
    AbstractTreeMap.Entry localEntry = find(paramDouble, 0);
    return localEntry == NIL ? Integer.MIN_VALUE : localEntry.val;
  }
  
  public int put(double paramDouble, int paramInt)
  {
    AbstractTreeMap.Entry localEntry = this.root;
    this.lastOrder = 0;
    if (localEntry == NIL)
    {
      incrementSize(true);
      this.root = new DoubleEntry(paramDouble, paramInt, NIL, this.lastOrder);
      return Integer.MIN_VALUE;
    }
    this.dummy.key = paramDouble;
    this.dummy.order = Integer.MAX_VALUE;
    for (;;)
    {
      int i = compare(this.dummy, localEntry);
      if (i == 0) {
        return localEntry.setValue(paramInt);
      }
      if (i < 0)
      {
        if (localEntry.left != NIL)
        {
          localEntry = localEntry.left;
        }
        else
        {
          incrementSize(this.lastOrder == 0);
          localEntry.left = new DoubleEntry(paramDouble, paramInt, localEntry, this.lastOrder);
          fixUpInsert(localEntry.left);
          return Integer.MIN_VALUE;
        }
      }
      else if (localEntry.right != NIL)
      {
        localEntry = localEntry.right;
      }
      else
      {
        incrementSize(this.lastOrder == 0);
        localEntry.right = new DoubleEntry(paramDouble, paramInt, localEntry, this.lastOrder);
        fixUpInsert(localEntry.right);
        return Integer.MIN_VALUE;
      }
    }
  }
  
  public int remove(double paramDouble)
  {
    AbstractTreeMap.Entry localEntry;
    if (this.allowDuplicates) {
      localEntry = findPredecessor(paramDouble, Integer.MAX_VALUE);
    } else {
      localEntry = find(paramDouble, 0);
    }
    if (localEntry == NIL) {
      return Integer.MIN_VALUE;
    }
    int i = localEntry.val;
    remove(localEntry);
    return i;
  }
  
  public int remove(double paramDouble, int paramInt)
  {
    AbstractTreeMap.Entry localEntry = findCeiling(paramDouble, 0);
    if ((localEntry != NIL) && (localEntry.getDoubleKey() != paramDouble)) {
      localEntry = successor(localEntry);
    }
    if ((localEntry == NIL) || (localEntry.getDoubleKey() != paramDouble)) {
      return Integer.MIN_VALUE;
    }
    while ((localEntry.val != paramInt) && (localEntry != NIL)) {
      localEntry = successor(localEntry);
    }
    if (localEntry == NIL) {
      return Integer.MIN_VALUE;
    }
    remove(localEntry);
    return paramInt;
  }
  
  public double firstKey()
  {
    return minimum(this.root).getDoubleKey();
  }
  
  public double lastKey()
  {
    return maximum(this.root).getDoubleKey();
  }
  
  public LiteralIterator keyIterator()
  {
    return new KeyIterator();
  }
  
  public LiteralIterator keyRangeIterator(double paramDouble1, boolean paramBoolean1, double paramDouble2, boolean paramBoolean2)
  {
    AbstractTreeMap.Entry localEntry1;
    AbstractTreeMap.Entry localEntry2;
    if (this.cmp.compare(paramDouble1, paramDouble2) <= 0)
    {
      localEntry1 = findCeiling(paramDouble1, paramBoolean1 ? 0 : Integer.MAX_VALUE);
      localEntry2 = findCeiling(paramDouble2, paramBoolean2 ? Integer.MAX_VALUE : 0);
    }
    else
    {
      localEntry1 = findCeiling(paramDouble1, paramBoolean1 ? Integer.MAX_VALUE : 0);
      localEntry1 = predecessor(localEntry1);
      localEntry2 = findCeiling(paramDouble2, paramBoolean2 ? 0 : Integer.MAX_VALUE);
      localEntry2 = predecessor(localEntry2);
    }
    return new KeyIterator(localEntry1, localEntry2);
  }
  
  public IntIterator valueRangeIterator(double paramDouble1, boolean paramBoolean1, double paramDouble2, boolean paramBoolean2)
  {
    return new AbstractTreeMap.ValueIterator(this, (AbstractTreeMap.EntryIterator)keyRangeIterator(paramDouble1, paramBoolean1, paramDouble2, paramBoolean2));
  }
  
  protected int compare(AbstractTreeMap.Entry paramEntry1, AbstractTreeMap.Entry paramEntry2)
  {
    int i = this.cmp.compare(paramEntry1.getDoubleKey(), paramEntry2.getDoubleKey());
    if ((this.allowDuplicates) && (i == 0))
    {
      i = paramEntry1.order > paramEntry2.order ? 1 : paramEntry1.order < paramEntry2.order ? -1 : 0;
      this.lastOrder = (1 + (i < 0 ? paramEntry1.order : paramEntry2.order));
    }
    return i;
  }
  
  private AbstractTreeMap.Entry find(double paramDouble, int paramInt)
  {
    this.dummy.key = paramDouble;
    this.dummy.order = paramInt;
    AbstractTreeMap.Entry localEntry = find(this.dummy);
    return localEntry;
  }
  
  private AbstractTreeMap.Entry findPredecessor(double paramDouble, int paramInt)
  {
    this.dummy.key = paramDouble;
    this.dummy.order = paramInt;
    AbstractTreeMap.Entry localEntry = findPredecessor(this.dummy);
    return localEntry;
  }
  
  private AbstractTreeMap.Entry findCeiling(double paramDouble, int paramInt)
  {
    this.dummy.key = paramDouble;
    this.dummy.order = paramInt;
    AbstractTreeMap.Entry localEntry = findCeiling(this.dummy);
    return localEntry;
  }
  
  private class KeyIterator
    extends AbstractTreeMap.KeyIterator
  {
    public KeyIterator()
    {
      super();
    }
    
    public KeyIterator(AbstractTreeMap.Entry paramEntry1, AbstractTreeMap.Entry paramEntry2)
    {
      super(paramEntry1, paramEntry2);
    }
    
    public boolean isDoubleSupported()
    {
      return true;
    }
    
    public double nextDouble()
    {
      return nextEntry().getDoubleKey();
    }
  }
  
  static class DoubleEntry
    extends AbstractTreeMap.Entry
  {
    double key;
    
    public DoubleEntry(double paramDouble, int paramInt)
    {
      super();
      this.key = paramDouble;
    }
    
    public DoubleEntry(double paramDouble, int paramInt1, AbstractTreeMap.Entry paramEntry, int paramInt2)
    {
      super(paramEntry, paramInt2);
      this.key = paramDouble;
    }
    
    public double getDoubleKey()
    {
      return this.key;
    }
    
    public Object getKey()
    {
      return new Double(this.key);
    }
    
    public boolean keyEquals(AbstractTreeMap.Entry paramEntry)
    {
      return ((paramEntry instanceof DoubleEntry)) && (this.key == ((DoubleEntry)paramEntry).key);
    }
    
    public boolean equals(Object paramObject)
    {
      if (!(paramObject instanceof DoubleEntry)) {
        return false;
      }
      DoubleEntry localDoubleEntry = (DoubleEntry)paramObject;
      return (this.key == localDoubleEntry.key) && (this.val == localDoubleEntry.val);
    }
    
    public int hashCode()
    {
      long l = Double.doubleToLongBits(this.key);
      int i = (int)(l ^ l >>> 32);
      int j = this.val;
      return i ^ j ^ this.order;
    }
    
    public String toString()
    {
      return this.key + "=" + this.val;
    }
    
    public void copyFields(AbstractTreeMap.Entry paramEntry)
    {
      super.copyFields(paramEntry);
      this.key = paramEntry.getDoubleKey();
    }
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\util\collections\DoubleIntTreeMap.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */