package prefuse.util.force;

import java.util.ArrayList;
import java.util.Iterator;

public class ForceSimulator
{
  private ArrayList items;
  private ArrayList springs;
  private Force[] iforces;
  private Force[] sforces;
  private int iflen;
  private int sflen;
  private Integrator integrator;
  private float speedLimit = 1.0F;
  
  public ForceSimulator()
  {
    this(new RungeKuttaIntegrator());
  }
  
  public ForceSimulator(Integrator paramIntegrator)
  {
    this.integrator = paramIntegrator;
    this.iforces = new Force[5];
    this.sforces = new Force[5];
    this.iflen = 0;
    this.sflen = 0;
    this.items = new ArrayList();
    this.springs = new ArrayList();
  }
  
  public float getSpeedLimit()
  {
    return this.speedLimit;
  }
  
  public void setSpeedLimit(float paramFloat)
  {
    this.speedLimit = paramFloat;
  }
  
  public Integrator getIntegrator()
  {
    return this.integrator;
  }
  
  public void setIntegrator(Integrator paramIntegrator)
  {
    this.integrator = paramIntegrator;
  }
  
  public void clear()
  {
    this.items.clear();
    Iterator localIterator = this.springs.iterator();
    Spring.SpringFactory localSpringFactory = Spring.getFactory();
    while (localIterator.hasNext()) {
      localSpringFactory.reclaim((Spring)localIterator.next());
    }
    this.springs.clear();
  }
  
  public void addForce(Force paramForce)
  {
    Force[] arrayOfForce;
    if (paramForce.isItemForce())
    {
      if (this.iforces.length == this.iflen)
      {
        arrayOfForce = new Force[this.iflen + 10];
        System.arraycopy(this.iforces, 0, arrayOfForce, 0, this.iforces.length);
        this.iforces = arrayOfForce;
      }
      this.iforces[(this.iflen++)] = paramForce;
    }
    if (paramForce.isSpringForce())
    {
      if (this.sforces.length == this.sflen)
      {
        arrayOfForce = new Force[this.sflen + 10];
        System.arraycopy(this.sforces, 0, arrayOfForce, 0, this.sforces.length);
        this.sforces = arrayOfForce;
      }
      this.sforces[(this.sflen++)] = paramForce;
    }
  }
  
  public Force[] getForces()
  {
    Force[] arrayOfForce = new Force[this.iflen + this.sflen];
    System.arraycopy(this.iforces, 0, arrayOfForce, 0, this.iflen);
    System.arraycopy(this.sforces, 0, arrayOfForce, this.iflen, this.sflen);
    return arrayOfForce;
  }
  
  public void addItem(ForceItem paramForceItem)
  {
    this.items.add(paramForceItem);
  }
  
  public boolean removeItem(ForceItem paramForceItem)
  {
    return this.items.remove(paramForceItem);
  }
  
  public Iterator getItems()
  {
    return this.items.iterator();
  }
  
  public Spring addSpring(ForceItem paramForceItem1, ForceItem paramForceItem2)
  {
    return addSpring(paramForceItem1, paramForceItem2, -1.0F, -1.0F);
  }
  
  public Spring addSpring(ForceItem paramForceItem1, ForceItem paramForceItem2, float paramFloat)
  {
    return addSpring(paramForceItem1, paramForceItem2, -1.0F, paramFloat);
  }
  
  public Spring addSpring(ForceItem paramForceItem1, ForceItem paramForceItem2, float paramFloat1, float paramFloat2)
  {
    if ((paramForceItem1 == null) || (paramForceItem2 == null)) {
      throw new IllegalArgumentException("ForceItems must be non-null");
    }
    Spring localSpring = Spring.getFactory().getSpring(paramForceItem1, paramForceItem2, paramFloat1, paramFloat2);
    this.springs.add(localSpring);
    return localSpring;
  }
  
  public Iterator getSprings()
  {
    return this.springs.iterator();
  }
  
  public void runSimulator(long paramLong)
  {
    accumulate();
    this.integrator.integrate(this, paramLong);
  }
  
  public void accumulate()
  {
    for (int i = 0; i < this.iflen; i++) {
      this.iforces[i].init(this);
    }
    for (i = 0; i < this.sflen; i++) {
      this.sforces[i].init(this);
    }
    Iterator localIterator = this.items.iterator();
    while (localIterator.hasNext())
    {
      localObject = (ForceItem)localIterator.next();
      ((ForceItem)localObject).force[0] = 0.0F;
      ((ForceItem)localObject).force[1] = 0.0F;
      for (int j = 0; j < this.iflen; j++) {
        this.iforces[j].getForce((ForceItem)localObject);
      }
    }
    Object localObject = this.springs.iterator();
    while (((Iterator)localObject).hasNext())
    {
      Spring localSpring = (Spring)((Iterator)localObject).next();
      for (int k = 0; k < this.sflen; k++) {
        this.sforces[k].getForce(localSpring);
      }
    }
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\util\force\ForceSimulator.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */